diff --git a/DOCUMENT.md b/DOCUMENT.md
new file mode 100644
index 00000000..a65a26c
--- /dev/null
+++ b/DOCUMENT.md
@@ -0,0 +1,150 @@
+# Discord.js Selfbot v13
+- Install: npm i discord.js-selfbot-v13@lasest
+## User Settings
+
+Click to show
+
+```js
+client.setting // Return Data Setting User;
+client.setting.setDisplayCompactMode(true | false); // Message Compact Mode
+client.setting.setTheme('dark' | 'light'); // Discord App theme
+client.setting.setLocale(value); // Set Language
+ /**
+ * * Locale Setting, must be one of:
+ * * `DANISH`
+ * * `GERMAN`
+ * * `ENGLISH_UK`
+ * * `ENGLISH_US`
+ * * `SPANISH`
+ * * `FRENCH`
+ * * `CROATIAN`
+ * * `ITALIAN`
+ * * `LITHUANIAN`
+ * * `HUNGARIAN`
+ * * `DUTCH`
+ * * `NORWEGIAN`
+ * * `POLISH`
+ * * `BRAZILIAN_PORTUGUESE`
+ * * `ROMANIA_ROMANIAN`
+ * * `FINNISH`
+ * * `SWEDISH`
+ * * `VIETNAMESE`
+ * * `TURKISH`
+ * * `CZECH`
+ * * `GREEK`
+ * * `BULGARIAN`
+ * * `RUSSIAN`
+ * * `UKRAINIAN`
+ * * `HINDI`
+ * * `THAI`
+ * * `CHINA_CHINESE`
+ * * `JAPANESE`
+ * * `TAIWAN_CHINESE`
+ * * `KOREAN`
+ * @param {string} value
+ * @returns {locale}
+ */
+```
+
+
+
+## Discord User Info
+
+Click to show
+
+Code:
+```js
+GuildMember.user.getProfile();
+// or
+User.getProfile();
+```
+Response
+```js
+User {
+ id: '721746046543331449',
+ bot: false,
+ system: false,
+ flags: UserFlagsBitField { bitfield: 256 },
+ friend: false,
+ blocked: false,
+ connectedAccounds: [],
+ premiumSince: 1623357181151,
+ premiumGuildSince: 0,
+ mutualGuilds: Collection(3) [Map] {
+ '906765260017516605' => { id: '906765260017516605', nick: null },
+ '809133733591384155' => { id: '809133733591384155', nick: 'uwu' },
+ '926065180788531261' => { id: '926065180788531261', nick: 'shiro' }
+ },
+ username: 'Shiraori',
+ discriminator: '1782',
+ avatar: 'f9ba7fb35b223e5f1a12eb910faa40c2',
+ banner: undefined,
+ accentColor: undefined
+}
+```
+
+
+## Discord User Friend / Blocked
+
+Click to show
+
+Code:
+```js
+GuildMember.user.setFriend();
+User.unFriend();
+Message.member.user.sendFriendRequest();
+// or
+GuildMember.user.setBlock();
+User.unBlock();
+```
+Response
+```js
+User {
+ id: '721746046543331449',
+ bot: false,
+ system: false,
+ flags: UserFlagsBitField { bitfield: 256 },
+ friend: false,
+ blocked: false,
+ connectedAccounds: [],
+ premiumSince: 1623357181151,
+ premiumGuildSince: 0,
+ mutualGuilds: Collection(3) [Map] {
+ '906765260017516605' => { id: '906765260017516605', nick: null },
+ '809133733591384155' => { id: '809133733591384155', nick: 'uwu' },
+ '926065180788531261' => { id: '926065180788531261', nick: 'shiro' }
+ },
+ username: 'Shiraori',
+ discriminator: '1782',
+ avatar: 'f9ba7fb35b223e5f1a12eb910faa40c2',
+ banner: undefined,
+ accentColor: undefined
+}
+```
+
+
+## Discord Guild set position
+
+Click to show
+
+Code:
+```js
+guild.setPosition(position, type, folderID);
+// Position: The guild's index in the directory or out of the directory
+// Type:
+// + 'FOLDER': Move guild to folder
+// + 'HOME': Move the guild out of the directory
+// FolderID: The folder's ID , if you want to move the guild to a folder
+```
+Response
+```js
+Guild
+```
+
+
+## More features
+
+
+Click to show
+- I need requests from you! Ask questions, I will help you!
+
\ No newline at end of file
diff --git a/README.md b/README.md
index 191aa0a..c759f2e 100644
--- a/README.md
+++ b/README.md
@@ -27,7 +27,8 @@
```sh-session
npm install discord.js-selfbot-v13
```
-
+## Patched
+Click [here](https://github.com/aiko-chan-ai/discord.js-selfbot-v13/blob/main/DOCUMENT.md) to see the patched functions
## Example
```js
diff --git a/package.json b/package.json
index 1f9f4bf..88eca0f 100644
--- a/package.json
+++ b/package.json
@@ -1,6 +1,6 @@
{
"name": "discord.js-selfbot-v13",
- "version": "0.1.6",
+ "version": "0.1.7",
"description": "A unofficial discord.js fork for creating selfbots [Based on discord.js v13]",
"main": "./src/index.js",
"types": "./typings/index.d.ts",
diff --git a/typings/index.d.ts b/typings/index.d.ts
index 110db31..e6ce24a 100644
--- a/typings/index.d.ts
+++ b/typings/index.d.ts
@@ -2404,10 +2404,11 @@ export class User extends PartialTextBasedChannel(Base) {
public equals(user: User): boolean;
public fetch(force?: boolean): Promise;
public fetchFlags(force?: boolean): Promise;
- public friend(): Promise;
- public block(): Promise;
- public unfriend(): Promise;
- public unblock(): Promise;
+ public setFriend(): Promise;
+ public setBlock(): Promise;
+ public sendFriendRequest(): Promise;
+ public unFriend(): Promise;
+ public unBlock(): Promise;
public getProfile(): Promise;
public toString(): UserMention;
}
diff --git a/src/structures/User.js b/src/structures/User.js
index d5c4833..762dfcb 100644
--- a/src/structures/User.js
+++ b/src/structures/User.js
@@ -158,21 +158,36 @@ class User extends Base {
}
/**
* Friends the user
* @returns {Promise} the user object
*/
- async friend() {
- return this.client.api
- .user('@me')
- .relationships[this.id].put({data:{type:1}})
- .then(_ => _)
+ async setFriend() {
+ return await this.client.api
+ .user('@me')
+ .relationships[this.id].put({ data: { type: 1 } })
+ .then((_) => _);
}
+ /**
+ * Send Friend Request to the user
+ * @returns {Promise} the user object
+ */
+ async sendFriendRequest() {
+ return await this.client.api
+ .users('@me')
+ .relationships.post({
+ data: {
+ username: this.username,
+ discriminator: parseInt(this.discriminator),
+ },
+ })
+ .then((_) => _);
+ }
/**
* Blocks the user
* @returns {Promise} the user object
*/
- async block() {
+ async setBlock() {
return this.client.api
.users('@me')
.relationships[this.id].put({data:{type: 2}})
@@ -183,7 +198,7 @@ class User extends Base {
* Removes the user from your blocks list
* @returns {Promise} the user object
*/
- async unblock() {
+ async unBlock() {
return this.client.api
.users('@me')
.relationships[this.id].delete
@@ -194,7 +209,7 @@ class User extends Base {
* Removes the user from your friends list
* @returns {Promise} the user object
*/
- async unfriend() {
+ async unFriend() {
return this.client.api
.users('@me')
.relationships[this.id].delete
@@ -158,21 +158,36 @@ class User extends Base {
}
/**
- * Friends the user
+ * Friends the user and send Request [If no request]
* @returns {Promise} the user object
*/